//===============================================================================================================
// XRayGlasses v2
// Original Author: Gopostal
// Edited Version: SpEcTra_7 a.k.a Rocky
//===============================================================================================================
class XRayGlassesv2 extends TournamentWeapon;

//Importing Pickup Meshes
#exec MESH IMPORT MESH=XRayGlass1st ANIVFILE=MODELS\XRayGlass1st_a.3d DATAFILE=MODELS\XRayGlass1st_d.3d X=0 Y=0 Z=0
#exec MESH ORIGIN MESH=XRayGlass1st X=0 Y=0 Z=0 Yaw=64

#exec MESH IMPORT MESH=XRayGlassPick ANIVFILE=MODELS\XRayGlassPick_a.3d DATAFILE=MODELS\XRayGlassPick_d.3d X=0 Y=0 Z=0
#exec MESH ORIGIN MESH=XRayGlassPick X=0 Y=0 Z=0

//Skins
#exec Texture Import Name=Glassy File="Textures\Glassy.bmp" LODSET=2
#exec MESHMAP SETTEXTURE MESHMAP=XRayGlass1st NUM=1 TEXTURE=Glassy
#exec MESHMAP SETTEXTURE MESHMAP=XRayGlassPick NUM=1 TEXTURE=Glassy

#exec Texture Import Name=GlassyB File="Textures\GlassyBody.bmp" LODSET=2
#exec MESHMAP SETTEXTURE MESHMAP=XRayGlass1st NUM=2 TEXTURE=GlassyB
#exec MESHMAP SETTEXTURE MESHMAP=XRayGlassPick NUM=2 TEXTURE=GlassyB

#exec Texture Import Name=GlassyH File="Textures\GlassyHand.bmp" LODSET=2
#exec MESHMAP SETTEXTURE MESHMAP=XRayGlass1st NUM=3 TEXTURE=GlassyH

//Animations
#exec MESH SEQUENCE MESH=XRayGlass1st SEQ=All STARTFRAME=0 NUMFRAMES=30
#exec MESH SEQUENCE MESH=XRayGlass1st SEQ=Select STARTFRAME=0 NUMFRAMES=12
#exec MESH SEQUENCE MESH=XRayGlass1st SEQ=Down STARTFRAME=13 NUMFRAMES=12
#exec MESH SEQUENCE MESH=XRayGlass1st SEQ=Still STARTFRAME=25 NUMFRAMES=5

#exec MESH SEQUENCE MESH=XRayGlassPick SEQ=All STARTFRAME=0 NUMFRAMES=30

//Scales
#exec MESHMAP NEW MESHMAP=XRayGlass1st MESH=XRayGlass1st
#exec MESHMAP SCALE MESHMAP=XRayGlass1st X=0.1 Y=0.1 Z=0.2

#exec MESHMAP NEW MESHMAP=XRayGlassPick MESH=XRayGlassPick
#exec MESHMAP SCALE MESHMAP=XRayGlassPick X=0.1 Y=0.1 Z=0.2

//Needed text for radar
#exec New TrueTypeFontFactory FontName="LucidaSansTypewriter" Name="BeaconNameFontSmall"  Height=8  USize=256 VSize=128 CharactersPerPage=256
#exec New TrueTypeFontFactory FontName="LucidaSansTypewriter" Name="BeaconNameFontMedium" Height=10 USize=256 VSize=128 CharactersPerPage=256
#exec New TrueTypeFontFactory FontName="LucidaSansTypewriter" Name="BeaconNameFontLarge"  Height=12 USize=256 VSize=256 CharactersPerPage=256
#exec Texture Import Name=TeamBeacon2 File="Textures\TeamBeacon2.bmp" Flags=2
#exec Texture Import Name=XRayGlassesBox File="Textures\XRayGlassesBox.bmp"
#exec Texture Import Name=GlassyIcon File="Textures\GlassyIcon.bmp" MIPS=OFF

var Texture TeamBeaconIcon;
var int d;

simulated function PlaySelect()
{
	PlayAnim('Select');
}

simulated function TweenDown()
{
	PlayAnim('Down');
}

function Fire( float Value )
{
}

function AltFire( float Value )
{
}

simulated function PostRender( canvas Canvas )
{
   local Pawn thisPawn;
   local vector X, Y, Z, CamLoc, TargetDir, Dir, XY;
   local rotator CamRot;
   local Actor Camera;
   local float BaseBeaconScale, BeaconScale, Dist, DistScale;
   local float TanFOVx, TanFOVy;
   local float TanX, TanY;
   local float dx, dy, FontY;
   local string BeaconText;
   
   Canvas.Style = ERenderStyle.STY_Masked;

   if (Canvas.ClipX > 1024)
      Canvas.Font = Font'BeaconNameFontLarge';
   else if (Canvas.ClipX > 640)
      Canvas.Font = Font'BeaconNameFontMedium';
   else
      Canvas.Font = Font'BeaconNameFontSmall';
	
   Canvas.SetPos(0, 0);
   Canvas.TextSize("X", dx, FontY);
   BaseBeaconScale = 1.5 * FontY / Texture'TeamBeacon2'.VSize;

   Canvas.ViewPort.Actor.PlayerCalcView(Camera, CamLoc, CamRot);

   TanFOVx = Tan(Canvas.ViewPort.Actor.FOVAngle / 114.591559);
   TanFOVy = (Canvas.ClipY / Canvas.ClipX) * TanFOVx;
   GetAxes(CamRot, X, Y, Z);

   Canvas.bNoSmooth = False;
   Canvas.Style = ERenderStyle.STY_Masked;

   foreach RadiusActors(class 'Pawn', thisPawn, 7000)
   {
      if ( thisPawn != none && thisPawn != Camera && thisPawn.Health > 0 && !thisPawn.bHidden)
      {
         TargetDir = thisPawn.Location - CamLoc;
	 		Dist = VSize(TargetDir) * FMin(TanFOVx, 1.0);
	 		TargetDir = Normal(TargetDir + vect(0,0,1) * thisPawn.CollisionHeight);
	 		DistScale = FMin(100.0 * thisPawn.CollisionRadius / Dist, 1.0);
	 		d = Dist;

	 		if (DistScale > 0.0 && TargetDir dot X > 0) 
			// These checks removed to allow wall hack
			// && (FastTrace(thisPawn.Location, CamLoc) || FastTrace(thisPawn.Location + vect(0,0,0.8) * thisPawn.CollisionHeight, CamLoc)))
         {
	    		BeaconScale = BaseBeaconScale * DistScale;
	   	 	Dir = X * (X dot TargetDir);
	    		XY = TargetDir - Dir;

	    		dx = Canvas.ClipX * 0.5 * (1.0 + (XY dot Y) / (VSize(Dir) * TanFOVx));
	    		dy = Canvas.ClipY * 0.5 * (1.0 - (XY dot Z) / (VSize(Dir) * TanFOVy));

	    		Canvas.SetPos(dx - 0.5 * BeaconScale * TeamBeaconIcon.USize, dy - 2 * FontY * DistScale);

	    		if (DistScale <= 1.0)
            {
	       		if (Canvas.ClipX > 600)
		  				BeaconText = "" $ d $ "";
               Canvas.DrawIcon(texture'CrossHair6', 1.0);
	       		Canvas.SetPos(dx + 0.6 * BeaconScale * TeamBeaconIcon.USize + 1, dy - 1.75 * FontY + 1);
	       		Canvas.DrawTextClipped(BeaconText, False);
            }
         }
      }
   }
}

defaultproperties
{
	TeamBeaconIcon=Texture'TeamBeacon2'
	WeaponDescription="Classification: XRay Glasses\n\nUsage: Equip them to see your enemies."
	PickupMessage="These glasses look...weird. I wonder what they do."
	ItemName="XRay Glasses"
	PlayerViewMesh=LodMesh'XRayGlassesv2.XRayGlass1st'
	PlayerViewOffset=(X=26.900000,Y=-0.300000,Z=-36.770000)
	PickupViewMesh=LodMesh'XRayGlassesv2.XRayGlassPick'
	PickupSound=Sound'UnrealShare.Pickups.WeaponPickup'
	Mesh=LodMesh'XRayGlassesv2.XRayGlassPick'
	Style=STY_Masked
	bNoSmooth=False
	LODBias=20.000000
	Icon=Texture'XRayGlassesv2.GlassyIcon'
	StatusIcon=Texture'XRayGlassesv2.GlassyIcon'
   //MultiSkins(0)=Texture'XRayGlassesBox'
   //MultiSkins(1)=Texture'XRayGlassesBox'
}